Description Public fields Active bindings Methods
Definition for 'RAVE' module class
Definition for 'RAVE' module class
debugwhether module is in debug mode
package'RAVE' module's package name
package_envpackage name space
package_configpackage configuration list
module_idmodule ID string
module_labelfriendly display name
module_groupmodule category
package_datalist storing package key-values pairs
containersstores run-time instances
package_rootpackage root directory, when running in debug context, returns module debug path, otherwise returns system package path
new()constructor
RAVEModule$new(package, module_id, force = FALSE, debug = FALSE)
packagecharacter package name
module_id'RAVE' module ID
forcewhether to force reload the source script
debugwhether to set in debug mode
add_container()Add run-time container instance
RAVEModule$add_container(session = shiny::getDefaultReactiveDomain())
sessionshiny session
get_path()get script paths
RAVEModule$get_path(path)
pathrelative or absolute, behaves slightly different when debugging modules, internally used
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.