start-app: Start 'RAVE' Applications

Description Usage Arguments Examples

Description

Use start_rave to launch applications; use view_layout to debug module.

Usage

1
2
3
4
5
6
7
8
9
start_rave(
  host = "127.0.0.1",
  port = NULL,
  launch_browser = TRUE,
  test_mode = FALSE,
  token = NULL,
  theme = "green",
  .adapter = dipsaus::fastmap2()
)

Arguments

host

IP address, default is '127.0.0.1'

port

integer port to listen to, default is NULL, and will be assigned a random port

launch_browser

whether to launch browser once the application is opened

test_mode

whether to enter test mode. Test mode does not release memory once application is closed, this will allow step-by-step debugging

token

token needed to launch application, default does not require any token

theme

passed to dashboardPage

.adapter

debug use, must be a fastmap2 instance. Combined with test_mode=TRUE, .adapter stores all container/module instances.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
if(interactive()){

  # Production
  start_rave()

  # Debug rave preprocess
  rave_context('rave_module_debug', package = 'ravetools',
               module_id = 'ravepreprocessoverview')
  view_layout()
}

dipterix/rave2 documentation built on Sept. 1, 2020, 12:07 a.m.